@@ -4,11 +4,11 @@ FACES: tuple = ("down", "up", "north", "south", "west", "east")						# Faces of
 SIDES: tuple = ("_bottom", "_top", "_front", "_back", "_left", "_right", "_side")	# Sides of a block, used for resource pack
 CUSTOM_BLOCK_VANILLA: str = "minecraft:furnace"			# Vanilla block used as base for custom blocks, must have the "facing" blockstate
 CUSTOM_BLOCK_ALTERNATIVE: str = "minecraft:item_frame"	# Same purpose as previous, but useful for blocks that can be placed on walls or on player's position (ex: flowers)
+CUSTOM_BLOCK_HEAD: str = "minecraft:player_head"		# Same purpose as previous, but useful for blocks does not have a custom model data
 CUSTOM_ITEM_VANILLA: str = "minecraft:command_block"	# Vanilla item used as base for custom items, must not have any survival vanilla behaviour
-MODEL_DISPLAY: dict = {"head":{"rotation":[0,0,0],"translation":[0,-30.42,0],"scale":[1.605,1.605,1.605]},"fixed":{"rotation":[-90,0,0],"translation":[0,0,-16],"scale":[2.0075,2.0075,2.0075]}}	# Model display base for custom blocks
 DOWNLOAD_VANILLA_ASSETS_RAW = "https://raw.githubusercontent.com/edayot/renders/renders/resourcepack/assets/minecraft/textures/render"
 DOWNLOAD_VANILLA_ASSETS_SOURCE = "https://github.com/edayot/renders/tree/renders/resourcepack/assets/minecraft/textures/render"
-
+CUSTOM_BLOCK_HEAD_CUBE_RADIUS: tuple[int, int, int] = (16, 16, 16)	# Size of the region to check around the player when placing a CUSTOM_BLOCK_HEAD
 
 # Databases
 RESULT_OF_CRAFTING: str = "result_of_crafting"			# Key to a list of recipes to craft the item, ex: "adamantium": {RESULT_OF_CRAFTING: [...]}
@@ -16,10 +16,10 @@ USED_FOR_CRAFTING: str = "used_for_crafting"			# Should not be used unless you a
 CATEGORY: str = "category"								# Key for the category, used for recipes and the manual, ex: CATEGORY:"material" or CATEGORY:"equipment"
 COMMANDS_ON_PLACEMENT: str = "commands_on_placement"	# Key to a list of commands to execute when a custom block is placed, should be a list of strings or a single string (with break lines if multiple commands)
 COMMANDS_ON_BREAK: str = "commands_on_break"			# Key to a list of commands to execute when a custom block is broken, should be a list of strings or a single string (with break lines if multiple commands)
-VANILLA_BLOCK: str = "vanilla_block"					# Key to a vanilla block that will be placed for custom block interaction, value needs to be a dict with id and block_states given {"id":"minecraft:chest", "block_states": ["facing", "type=single", "waterlogged=false"]}
+VANILLA_BLOCK: str = "vanilla_block"					# Key to a vanilla block that will be placed for custom block interaction, value needs to be a dict like {"id":"minecraft:chest[type=single,waterlogged=false]", "apply_facing": True}
 NO_SILK_TOUCH_DROP: str = "no_silk_touch_drop"			# Key to an item ID that will drop when silk touch is not used. Must be used only when using the vanilla block for ores, ex: "adamantium_fragment" or "minecraft:raw_iron"
 OVERRIDE_MODEL: str = "override_model"					# Key to a dictionnary that will be used to override the whole model
-VANILLA_BLOCK_FOR_ORES: dict = {"id":"minecraft:polished_deepslate","block_states":[]}	# Vanilla block that will be used for an optimization tip for ores, don't ask questions
+VANILLA_BLOCK_FOR_ORES: dict = {"id":"minecraft:polished_deepslate", "apply_facing": False}	# Vanilla block that will be used for an optimization tip for ores, don't ask questions
 NOT_COMPONENTS: list[str] = [							# Keys that should not be considered as components. Used for recipes, loot tables, etc.
 	"id",
 	"wiki",
@@ -33,3 +33,16 @@ NOT_COMPONENTS: list[str] = [							# Keys that should not be considered as comp
 	OVERRIDE_MODEL,
 ]
 
+# Automatically handled dependencies for supported libs with additional key "is_used" that is True when the lib is found to be used.
+def official_lib_used(lib: str) -> bool:
+	is_used: bool = OFFICIAL_LIBS[lib]["is_used"]
+	OFFICIAL_LIBS[lib]["is_used"] = True
+	return is_used
+OFFICIAL_LIBS: dict[str, dict[str, list[int] | str | bool]] = {
+	"common_signals":		{"version":[0, 0, 3], "name":"Common Signals",					"url":"https://github.com/Stoupy51/CommonSignals",			"is_used": False},
+	"smithed.custom_block":	{"version":[0, 3, 0], "name":"Smithed Custom Block",			"url":"https://wiki.smithed.dev/libraries/custom-block/",	"is_used": False},
+	"smithed.crafter":		{"version":[0, 3, 1], "name":"Smithed Crafter",					"url":"https://wiki.smithed.dev/libraries/crafter/",		"is_used": False},
+	"furnace_nbt_recipes":	{"version":[1, 4, 0], "name":"Furnace NBT Recipes",				"url":"https://github.com/Stoupy51/FurnaceNbtRecipes",		"is_used": False},
+	"smart_ore_generation":	{"version":[1, 3, 0], "name":"Smart Ore Generation",			"url":"https://github.com/Stoupy51/SmartOreGeneration",		"is_used": False},
+}
+
