@@ -30,10 +30,19 @@ NONE_FONT = get_font(0x0000)
 MEDIUM_NONE_FONT = get_font(0x0001)
 SMALL_NONE_FONT = get_font(0x0002)
 VERY_SMALL_NONE_FONT = get_font(0x0003)
-WIKI_NONE_FONT = get_font(0x0004)
-WIKI_INFO_FONT = get_font(0x0005)
-WIKI_RESULT_OF_CRAFT_FONT = get_font(0x0006)
-WIKI_INGR_OF_CRAFT_FONT = get_font(0x0007)
+MICRO_NONE_FONT = get_font(0x0004)
+WIKI_NONE_FONT = get_font(0x0005)
+WIKI_INFO_FONT = get_font(0x0006)
+WIKI_RESULT_OF_CRAFT_FONT = get_font(0x0007)
+WIKI_INGR_OF_CRAFT_FONT = get_font(0x0008)
+SHAPED_2X2_FONT = get_font(0x0009)
+SHAPED_3X3_FONT = get_font(0x000A)
+FURNACE_FONT = get_font(0x000B)
+HOVER_SHAPED_2X2_FONT = get_font(0x000C)
+HOVER_SHAPED_3X3_FONT = get_font(0x000D)
+HOVER_FURNACE_FONT = get_font(0x000E)
+INVISIBLE_ITEM_FONT = get_font(0x000F)	# Invisible item to place
+INVISIBLE_ITEM_WIDTH = INVISIBLE_ITEM_FONT + MICRO_NONE_FONT
 
 # Global variables
 next_craft_font = 0x8000
